use diesel::prelude::*;
use serde::{de::DeserializeOwned, Serialize};

pub trait CrudEntity: Sized + Serialize {
    type Id: Serialize + DeserializeOwned + 'static;
    type CreateInput: DeserializeOwned + 'static;
    type UpdateInput: DeserializeOwned + 'static;

    fn find_all(conn: &mut PgConnection, limit: Option<i64>, offset: Option<i64>) -> Result<Vec<Self>, diesel::result::Error>;
    fn find_by_id(conn: &mut PgConnection, id: Self::Id) -> Result<Self, diesel::result::Error>;
    fn insert(conn: &mut PgConnection, item: Self::CreateInput) -> Result<Self, diesel::result::Error>;
    fn update(conn: &mut PgConnection, id: Self::Id, item: Self::UpdateInput) -> Result<Self, diesel::result::Error>;
    fn delete(conn: &mut PgConnection, id: Self::Id) -> Result<usize, diesel::result::Error>;
}