use actix_web::{web, App, HttpServer};
use db::connection::establish_connection_pool;
use models::user::User;
use routes::crud::add_crud_routes;

mod crud;
mod models;
mod db;
mod routes;
mod schema;

#[actix_web::main]
async fn main() -> std::io::Result<()> {
    let pool = establish_connection_pool();

    HttpServer::new(move || {
        let mut app = App::new().app_data(web::Data::new(pool.clone()));
        app = add_crud_routes::<User>(app, "/users");
        app
    })
    .bind("0.0.0.0:3000")?
    .run()
    .await
}
